#[non_exhaustive]pub struct RoomPowerLevelsEventContent {
pub ban: Int,
pub events: BTreeMap<TimelineEventType, Int>,
pub events_default: Int,
pub invite: Int,
pub kick: Int,
pub redact: Int,
pub state_default: Int,
pub users: BTreeMap<OwnedUserId, Int>,
pub users_default: Int,
pub notifications: NotificationPowerLevels,
}Expand description
The content of an m.room.power_levels event.
Defines the power levels (privileges) of users in the room.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ban: IntThe level required to ban a user.
events: BTreeMap<TimelineEventType, Int>The level required to send specific event types.
This is a mapping from event type to power level required.
events_default: IntThe default level required to send message events.
invite: IntThe level required to invite a user.
kick: IntThe level required to kick a user.
redact: IntThe level required to redact an event.
state_default: IntThe default level required to send state events.
users: BTreeMap<OwnedUserId, Int>The power levels for specific users.
This is a mapping from user_id to power level for that user.
users_default: IntThe default power level for every user in the room.
notifications: NotificationPowerLevelsThe power level requirements for specific notification types.
This is a mapping from key to power level for that notifications key.
Implementations
Sourceimpl RoomPowerLevelsEventContent
impl RoomPowerLevelsEventContent
Sourcepub fn new(rules: &AuthorizationRules) -> Self
pub fn new(rules: &AuthorizationRules) -> Self
Creates a new RoomPowerLevelsEventContent with all-default values for the given
authorization rules.